@@ -73,7 +73,7 @@ def check_and_notify(job, config, n_unique, n_have, n_generated):
                 print('Continuing without the missing dihedrals...\n')
             else:
                 print('Exiting...\n')
-                sys.exit()
+                raise SystemExit
 
 
 class Fragment():
@@ -205,7 +205,7 @@ class Fragment():
             self.map_mol_to_frag[cap['idx']] = self.n_atoms_without_cap + cap['n_cap']
             h_type = f'1(1.0){mol.topo.elements[cap["connected"]]}'
             self.graph.add_node(self.n_atoms_without_cap + cap['n_cap'], elem=1, n_bonds=1,
-                                lone_e=0, coords=cap['coord'], capping=True)
+                                coords=cap['coord'], capping=True)
             self.graph.add_edge(self.n_atoms_without_cap + cap['n_cap'],
                                 self.map_mol_to_frag[cap["connected"]], type=h_type)
 
@@ -215,7 +215,7 @@ class Fragment():
     def make_fragment_identifier(self, config, mol, qm):
         atom_ids = [[], []]
         comp_dict = {i: 0 for i in set(self.elements[:self.n_atoms_without_cap])}
-        if 1 not in comp_dict.keys() and len(self.cap) > 0:
+        if 1 not in comp_dict.keys() and len(self.caps) > 0:
             comp_dict[1] = 0
 
         for a in range(2):
@@ -260,7 +260,7 @@ class Fragment():
         self.map_frag_to_db = {i: i for i in range(self.n_atoms)}
         have_match = False
 
-        nm = iso.categorical_node_match(['elem', 'n_bonds', 'lone_e', 'capping', 'scan'],
+        nm = iso.categorical_node_match(['elem', 'n_bonds', 'capping', 'scan'],
                                         [0, 0, 0, False, False])
         em = iso.categorical_edge_match(['type'], [0])
 
